/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/kms/KMSRequest.h>
#include <aws/kms/KMS_EXPORTS.h>
#include <aws/kms/model/IncludeKeyMaterial.h>

#include <utility>

namespace Aws {
namespace KMS {
namespace Model {

/**
 */
class ListKeyRotationsRequest : public KMSRequest {
 public:
  AWS_KMS_API ListKeyRotationsRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "ListKeyRotations"; }

  AWS_KMS_API Aws::String SerializePayload() const override;

  AWS_KMS_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>Gets the key rotations for the specified KMS key.</p> <p>Specify the key ID
   * or key ARN of the KMS key.</p> <p>For example:</p> <ul> <li> <p>Key ID:
   * <code>1234abcd-12ab-34cd-56ef-1234567890ab</code> </p> </li> <li> <p>Key ARN:
   * <code>arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab</code>
   * </p> </li> </ul> <p>To get the key ID and key ARN for a KMS key, use
   * <a>ListKeys</a> or <a>DescribeKey</a>.</p>
   */
  inline const Aws::String& GetKeyId() const { return m_keyId; }
  inline bool KeyIdHasBeenSet() const { return m_keyIdHasBeenSet; }
  template <typename KeyIdT = Aws::String>
  void SetKeyId(KeyIdT&& value) {
    m_keyIdHasBeenSet = true;
    m_keyId = std::forward<KeyIdT>(value);
  }
  template <typename KeyIdT = Aws::String>
  ListKeyRotationsRequest& WithKeyId(KeyIdT&& value) {
    SetKeyId(std::forward<KeyIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Use this optional parameter to control which key materials associated with
   * this key are listed in the response. The default value of this parameter is
   * <code>ROTATIONS_ONLY</code>. If you omit this parameter, KMS returns information
   * on the key materials created by automatic or on-demand key rotation. When you
   * specify a value of <code>ALL_KEY_MATERIAL</code>, KMS adds the first key
   * material and any imported key material pending rotation to the response. This
   * parameter can only be used with KMS keys that support automatic or on-demand key
   * rotation. </p>
   */
  inline IncludeKeyMaterial GetIncludeKeyMaterial() const { return m_includeKeyMaterial; }
  inline bool IncludeKeyMaterialHasBeenSet() const { return m_includeKeyMaterialHasBeenSet; }
  inline void SetIncludeKeyMaterial(IncludeKeyMaterial value) {
    m_includeKeyMaterialHasBeenSet = true;
    m_includeKeyMaterial = value;
  }
  inline ListKeyRotationsRequest& WithIncludeKeyMaterial(IncludeKeyMaterial value) {
    SetIncludeKeyMaterial(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Use this parameter to specify the maximum number of items to return. When
   * this value is present, KMS does not return more than the specified number of
   * items, but it might return fewer.</p> <p>This value is optional. If you include
   * a value, it must be between 1 and 1000, inclusive. If you do not include a
   * value, it defaults to 100.</p>
   */
  inline int GetLimit() const { return m_limit; }
  inline bool LimitHasBeenSet() const { return m_limitHasBeenSet; }
  inline void SetLimit(int value) {
    m_limitHasBeenSet = true;
    m_limit = value;
  }
  inline ListKeyRotationsRequest& WithLimit(int value) {
    SetLimit(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Use this parameter in a subsequent request after you receive a response with
   * truncated results. Set it to the value of <code>NextMarker</code> from the
   * truncated response you just received.</p>
   */
  inline const Aws::String& GetMarker() const { return m_marker; }
  inline bool MarkerHasBeenSet() const { return m_markerHasBeenSet; }
  template <typename MarkerT = Aws::String>
  void SetMarker(MarkerT&& value) {
    m_markerHasBeenSet = true;
    m_marker = std::forward<MarkerT>(value);
  }
  template <typename MarkerT = Aws::String>
  ListKeyRotationsRequest& WithMarker(MarkerT&& value) {
    SetMarker(std::forward<MarkerT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_keyId;

  IncludeKeyMaterial m_includeKeyMaterial{IncludeKeyMaterial::NOT_SET};

  int m_limit{0};

  Aws::String m_marker;
  bool m_keyIdHasBeenSet = false;
  bool m_includeKeyMaterialHasBeenSet = false;
  bool m_limitHasBeenSet = false;
  bool m_markerHasBeenSet = false;
};

}  // namespace Model
}  // namespace KMS
}  // namespace Aws
